==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/core/iinteractoreventrecorder.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef IINTERACTOREVENTRECORDER_H
#define IINTERACTOREVENTRECORDER_H

#include <vtkInteractorEventRecorder.h>

class iInteractorEventRecorder : public vtkInteractorEventRecorder
{
	
public:
	
	static iInteractorEventRecorder* New(){ return new iInteractorEventRecorder; }
	
	void SetFileName(const char *s);
	
	bool IsPlaying() const;
	bool IsRecording() const;
	bool IsStopped() const;
	bool IsAtEnd() const;

	void Record();
	void Play();
	void Stop();
	void Rewind();
	
protected:
	
	iInteractorEventRecorder();
	virtual ~iInteractorEventRecorder(){}
	
private:

	bool mStopped;
};

#endif // IINTERACTOREVENTRECORDER_H

==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/core/iinteractoreventrecorder.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef IINTERACTOREVENTRECORDER_H
#define IINTERACTOREVENTRECORDER_H


#include <vtkInteractorEventRecorder.h>


class iInteractorEventRecorder : public vtkInteractorEventRecorder
{
	
public:
	
	vtkTypeMacro(iInteractorEventRecorder,vtkInteractorEventRecorder);
	static iInteractorEventRecorder* New(){ return new iInteractorEventRecorder; }
	
	void SetFileName(const char *s);
	
	bool IsPlaying() const;
	bool IsRecording() const;
	bool IsStopped() const;
	bool IsAtEnd() const;

	void Record();
	void Play();
	void Stop();
	void Rewind();

protected:

	virtual ~iInteractorEventRecorder();

private:
	
	iInteractorEventRecorder();
	
	bool mStopped;
};

#endif // IINTERACTOREVENTRECORDER_H
